from dispositor.space import Space


class Chain:
    """
    Этот класс возвращает данные только для цепочки диспозиторов (части цепочки, содержимое части (планеты с орбитами))
    Предположительно изначально будет расчет вестись без учета орбит. Поэтому пока данный класс не реализуется.
    """
    def __init__(self, space):
        self.space = space