from setuptools import setup

setup(name='dispositor',
      version='1.2',
      description='Library for calculating the zodiac sign',
      packages=['dispositor'],
      author_email='astro.slfd@gmail.com',
      zip_safe=False)